'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const index = require('./index-d1efcaa6.js');
const utils = require('./utils-7bf97306.js');

class Point {
  constructor(x, y) {
    this.x = x;
    this.y = y;
  }
}

class Vector {
  /**
   * Gets a vector to determine direction between two points
   * @param {number} x The direction this vector goes on the x-axis
   * @param {number} y The direction this vector goes on the y-axis
   */
  constructor(x, y) {
    this.x = x;
    this.y = y;
  }
  /**
   * Returns a normalized version of this vector (between -1 and 1);
   *
   * @return Point
   */
  get normalized() {
    return new Point(this.x / Math.abs(this.x), this.y / Math.abs(this.y));
  }
  /**
   * Returns an interval [-1, 1] of this vector.
   *
   * @param {Point} max
   *
   * @returns {Point}
   */
  interval(max) {
    return new Point(this.x / max.x, this.y / max.y);
  }
}

class Plane {
  constructor(width, height) {
    this.width = width;
    this.height = height;
    this.width = width;
    this.height = height;
    this.center = new Point(width / 2, height / 2);
    this.area = this.width * this.height;
  }
  /**
   * @param {Point} Point
   *
   * @return Vector;
   */
  getPointVectorFromCenter(Point) {
    return new Vector(Point.x - this.center.x, this.center.y - Point.y);
  }
  /**
   * @param {Point} Point
   */
  _isPointInside(Point) {
    return Point.x < this.width && Point.x > 0 && Point.y > 0 && Point.y < this.height;
  }
  /**
   * @return Point
   */
  get outerEdge() {
    return new Point(this.width, this.height);
  }
}

const wrCaseHighlightCss = ".perspective-wrapper{-webkit-perspective:1200px;perspective:1200px;-webkit-transform-style:preserve-3d;transform-style:preserve-3d}.case-card{-webkit-transition-property:-webkit-transform;transition-property:-webkit-transform;transition-property:transform;transition-property:transform, -webkit-transform;-webkit-transition-timing-function:cubic-bezier(0.4, 0, 0.2, 1);transition-timing-function:cubic-bezier(0.4, 0, 0.2, 1);-webkit-transition-duration:150ms;transition-duration:150ms;-webkit-transition-duration:300ms;transition-duration:300ms;-webkit-transition-timing-function:cubic-bezier(0, 0, 0.2, 1);transition-timing-function:cubic-bezier(0, 0, 0.2, 1);border-radius:.25rem;position:relative;width:100%;display:-ms-flexbox;display:flex;overflow:hidden;--tw-bg-opacity:1;background-color:rgba(245, 149, 6, var(--tw-bg-opacity));height:15rem;--rotate-x:0;--rotate-y:0;will-change:transform}.case-card__background{-webkit-transition-property:-webkit-transform;transition-property:-webkit-transform;transition-property:transform;transition-property:transform, -webkit-transform;-webkit-transition-timing-function:cubic-bezier(0.4, 0, 0.2, 1);transition-timing-function:cubic-bezier(0.4, 0, 0.2, 1);-webkit-transition-duration:150ms;transition-duration:150ms;-webkit-transition-duration:300ms;transition-duration:300ms;-webkit-transition-timing-function:cubic-bezier(0, 0, 0.2, 1);transition-timing-function:cubic-bezier(0, 0, 0.2, 1);display:block;position:absolute;top:0px;right:0px;bottom:0px;left:0px;border-radius:.25rem;--tw-scale-x:1.25;--tw-scale-y:1.25;-webkit-transform:var(--tw-transform);transform:var(--tw-transform);transform:var(--tw-transform);-o-object-fit:cover;object-fit:cover;height:100%;width:100%;background-position:var(--preferred-x) var(--preferred-y)}.case-card__footer{-webkit-transition-property:-webkit-transform;transition-property:-webkit-transform;transition-property:transform;transition-property:transform, -webkit-transform;-webkit-transition-timing-function:cubic-bezier(0.4, 0, 0.2, 1);transition-timing-function:cubic-bezier(0.4, 0, 0.2, 1);-webkit-transition-duration:150ms;transition-duration:150ms;-webkit-transition-duration:300ms;transition-duration:300ms;-webkit-transition-timing-function:cubic-bezier(0, 0, 0.2, 1);transition-timing-function:cubic-bezier(0, 0, 0.2, 1);margin-top:auto;padding-left:1rem;display:-ms-flexbox;display:flex;-ms-flex-align:center;align-items:center;width:100%;position:relative;z-index:1;pointer-events:none}.case-card__link{position:absolute;top:0px;right:0px;bottom:0px;left:0px;background-image:-webkit-gradient(linear, left top, left bottom, from(rgba(53, 53, 53, 0.0001)), color-stop(99.29%, rgba(0, 0, 0, 0.8)));background-image:linear-gradient(180deg, rgba(53, 53, 53, 0.0001) 0%, rgba(0, 0, 0, 0.8) 99.29%)}.case-card h3{--tw-text-opacity:1;color:rgba(255, 255, 255, var(--tw-text-opacity));margin-top:0px;margin-bottom:0px}.case-card__button{-webkit-transition-property:background-color, border-color, color, fill, stroke;transition-property:background-color, border-color, color, fill, stroke;-webkit-transition-timing-function:cubic-bezier(0.4, 0, 0.2, 1);transition-timing-function:cubic-bezier(0.4, 0, 0.2, 1);-webkit-transition-duration:150ms;transition-duration:150ms;-webkit-transition-duration:225ms;transition-duration:225ms;-webkit-transition-timing-function:cubic-bezier(0.4, 0, 1, 1);transition-timing-function:cubic-bezier(0.4, 0, 1, 1);display:-ms-flexbox;display:flex;-ms-flex-align:center;align-items:center;-ms-flex-pack:center;justify-content:center;margin-left:auto;height:3rem;width:3rem;padding:0px;--tw-bg-opacity:1;background-color:rgba(26, 26, 26, var(--tw-bg-opacity));--tw-text-opacity:1;color:rgba(255, 255, 255, var(--tw-text-opacity));border-top-left-radius:.25rem;border-bottom-right-radius:.25rem;border-width:0px;margin-left:auto}.case-card:hover{-webkit-transition-property:-webkit-transform;transition-property:-webkit-transform;transition-property:transform;transition-property:transform, -webkit-transform;-webkit-transition-timing-function:cubic-bezier(0.4, 0, 0.2, 1);transition-timing-function:cubic-bezier(0.4, 0, 0.2, 1);-webkit-transition-duration:150ms;transition-duration:150ms;-webkit-transition-duration:100ms;transition-duration:100ms;-webkit-transition-timing-function:cubic-bezier(0.4, 0, 1, 1);transition-timing-function:cubic-bezier(0.4, 0, 1, 1);--tw-shadow:0 12px 25px rgb(0, 0, 0, 0.05);-webkit-box-shadow:var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow);box-shadow:var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow);-webkit-transform:translate3d(0, 0, 2rem) rotateX(var(--rotate-y)) rotateY(var(--rotate-x));transform:translate3d(0, 0, 2rem) rotateX(var(--rotate-y)) rotateY(var(--rotate-x))}.case-card:hover .case-card__button{-webkit-transition-property:background-color, border-color, color, fill, stroke;transition-property:background-color, border-color, color, fill, stroke;-webkit-transition-timing-function:cubic-bezier(0.4, 0, 0.2, 1);transition-timing-function:cubic-bezier(0.4, 0, 0.2, 1);-webkit-transition-duration:150ms;transition-duration:150ms;-webkit-transition-duration:100ms;transition-duration:100ms;-webkit-transition-timing-function:cubic-bezier(0.4, 0, 1, 1);transition-timing-function:cubic-bezier(0.4, 0, 1, 1);--tw-bg-opacity:1;background-color:rgba(245, 149, 6, var(--tw-bg-opacity))}.case-card:hover .case-card__background{-webkit-transition-property:-webkit-transform;transition-property:-webkit-transform;transition-property:transform;transition-property:transform, -webkit-transform;-webkit-transition-timing-function:cubic-bezier(0.4, 0, 0.2, 1);transition-timing-function:cubic-bezier(0.4, 0, 0.2, 1);-webkit-transition-duration:150ms;transition-duration:150ms;-webkit-transition-duration:225ms;transition-duration:225ms;-webkit-transition-timing-function:linear;transition-timing-function:linear}.case-card:hover h3{-webkit-transition-property:-webkit-transform;transition-property:-webkit-transform;transition-property:transform;transition-property:transform, -webkit-transform;-webkit-transition-timing-function:cubic-bezier(0.4, 0, 0.2, 1);transition-timing-function:cubic-bezier(0.4, 0, 0.2, 1);-webkit-transition-duration:150ms;transition-duration:150ms;-webkit-transition-duration:225ms;transition-duration:225ms;-webkit-transition-timing-function:cubic-bezier(0.4, 0, 1, 1);transition-timing-function:cubic-bezier(0.4, 0, 1, 1);-webkit-transform:translate3d(calc(var(--translate-x) * -1.25), calc(var(--translate-y) * -1.25), 2rem);transform:translate3d(calc(var(--translate-x) * -1.25), calc(var(--translate-y) * -1.25), 2rem);-webkit-transform-origin:left bottom;transform-origin:left bottom}";

let WrCaseHighlight = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    this.backgroundX = '50%';
    this.backgroundY = '50%';
  }
  componentDidLoad() {
    this.card.addEventListener('mousemove', utils.throttle(this.handleMouseOver.bind(this), 16));
    this.card.addEventListener('mouseout', this.handleMouseLeave.bind(this));
  }
  handleMouseLeave() {
    const target = this.card;
    target.style.setProperty('--rotate-x', `0deg`);
    target.style.setProperty('--rotate-y', `0deg`);
  }
  handleMouseOver(event) {
    const target = this.card;
    const plane = new Plane(target.clientWidth, target.clientHeight);
    const point = new Point(event.offsetX, event.offsetY);
    const vector = plane.getPointVectorFromCenter(point);
    target.style.setProperty('--rotate-x', `${vector.interval(plane.outerEdge).x * 12}deg`);
    target.style.setProperty('--translate-x', `${vector.interval(plane.outerEdge).x * 12}%`);
    target.style.setProperty('--rotate-y', `${vector.interval(plane.outerEdge).y * 25}deg`);
    target.style.setProperty('--translate-y', `${vector.interval(plane.outerEdge).y * 25}%`);
  }
  render() {
    return (index.h("div", { class: 'perspective-wrapper' }, index.h("article", { class: 'case-card', ref: (el) => this.card = el }, this.renderImage(), index.h("a", { class: 'case-card__link', href: this.href, "aria-label": `Bekijk ${this.caseTitle}` }), index.h("footer", { class: 'case-card__footer' }, index.h("h3", { class: 'is-h6' }, this.caseTitle), index.h("button", { class: 'case-card__button', "aria-label": `Bekijk ${this.caseTitle}` }, this.renderPlayArrow())))));
  }
  renderImage() {
    return index.h("img", { class: 'case-card__background', loading: 'lazy', src: this.background, alt: '', srcset: this.backgroundSrcSet });
  }
  renderPlayArrow() {
    return (index.h("svg", { width: '10', height: '12', viewBox: '0 0 10 12', fill: 'none', xmlns: 'http://www.w3.org/2000/svg', class: 'play-arrow' }, index.h("path", { d: 'M0 1.49946C0.00724877 1.22427 0.0894759 0.955945 0.238208 0.722137C0.38694 0.48833 0.596797 0.297496 0.846152 0.169301C1.08606 0.0475163 1.35458 -0.0103541 1.62467 0.00151974C1.89476 0.0133936 2.15687 0.0945922 2.38461 0.236936L9.30768 4.74594C9.52148 4.88349 9.69677 5.07099 9.81766 5.29145C9.93855 5.51191 10.0012 5.75836 9.99998 6.00846C9.99911 6.25338 9.93697 6.49439 9.819 6.7105C9.70102 6.92661 9.53077 7.11128 9.32306 7.24843L2.32307 11.7574C2.0971 11.9047 1.83392 11.9882 1.5625 11.9988C1.29107 12.0095 1.02191 11.9467 0.784614 11.8176C0.548105 11.6877 0.350957 11.499 0.213162 11.2707C0.0753673 11.0424 0.00182731 10.7825 0 10.5175L0 1.49946Z', fill: 'currentColor' })));
  }
  get host() { return index.getElement(this); }
};
WrCaseHighlight.style = wrCaseHighlightCss;

exports.wr_case_highlight = WrCaseHighlight;
