'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const index = require('./index-d1efcaa6.js');

/**
 * Atropos 1.0.1
 * Touch-friendly 3D parallax hover effects
 * https://atroposjs.com
 *
 * Copyright 2021-2021 
 *
 * Released under the MIT License
 *
 * Released on: October 18, 2021
 */

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

/* eslint-disable no-restricted-globals */
var $ = function $(el, sel) {
  return el.querySelector(sel);
};

var $$ = function $$(el, sel) {
  return el.querySelectorAll(sel);
};

var removeUndefinedProps = function removeUndefinedProps(obj) {
  if (obj === void 0) {
    obj = {};
  }

  var result = {};
  Object.keys(obj).forEach(function (key) {
    if (typeof obj[key] !== 'undefined') result[key] = obj[key];
  });
  return result;
};

function Atropos(originalParams) {
  if (originalParams === void 0) {
    originalParams = {};
  }

  var _originalParams = originalParams,
      el = _originalParams.el,
      eventsEl = _originalParams.eventsEl;
  var self = {
    __atropos__: true,
    params: _extends({
      alwaysActive: false,
      activeOffset: 50,
      shadowOffset: 50,
      shadowScale: 1,
      duration: 300,
      rotate: true,
      rotateTouch: true,
      rotateXMax: 15,
      rotateYMax: 15,
      rotateXInvert: false,
      rotateYInvert: false,
      stretchX: 0,
      stretchY: 0,
      stretchZ: 0,
      commonOrigin: true,
      shadow: true,
      highlight: true,
      onEnter: null,
      onLeave: null,
      onRotate: null
    }, removeUndefinedProps(originalParams || {})),
    destroyed: false,
    isActive: false
  };
  var params = self.params;
  var rotateEl;
  var scaleEl;
  var innerEl;
  var elBoundingClientRect;
  var eventsElBoundingClientRect;
  var shadowEl;
  var highlightEl;
  var isScrolling;
  var clientXStart;
  var clientYStart;
  var queue = [];
  var queueFrameId;

  var purgeQueue = function purgeQueue() {
    queueFrameId = requestAnimationFrame(function () {
      queue.forEach(function (data) {
        if (typeof data === 'function') {
          data();
        } else {
          var element = data.element,
              prop = data.prop,
              value = data.value;
          element.style[prop] = value;
        }
      });
      queue.splice(0, queue.length);
      purgeQueue();
    });
  };

  purgeQueue();

  var $setDuration = function $setDuration(element, value) {
    queue.push({
      element: element,
      prop: 'transitionDuration',
      value: value
    });
  };

  var $setEasing = function $setEasing(element, value) {
    queue.push({
      element: element,
      prop: 'transitionTimingFunction',
      value: value
    });
  };

  var $setTransform = function $setTransform(element, value) {
    queue.push({
      element: element,
      prop: 'transform',
      value: value
    });
  };

  var $setOpacity = function $setOpacity(element, value) {
    queue.push({
      element: element,
      prop: 'opacity',
      value: value
    });
  };

  var $setOrigin = function $setOrigin(element, value) {
    queue.push({
      element: element,
      prop: 'transformOrigin',
      value: value
    });
  };

  var $on = function $on(element, event, handler, props) {
    return element.addEventListener(event, handler, props);
  };

  var $off = function $off(element, event, handler, props) {
    return element.removeEventListener(event, handler, props);
  };

  var createShadow = function createShadow() {
    var created;
    shadowEl = $(el, '.atropos-shadow');

    if (!shadowEl) {
      shadowEl = document.createElement('span');
      shadowEl.classList.add('atropos-shadow');
      created = true;
    }

    $setTransform(shadowEl, "translate3d(0,0,-" + params.shadowOffset + "px) scale(" + params.shadowScale + ")");

    if (created) {
      rotateEl.appendChild(shadowEl);
    }
  };

  var createHighlight = function createHighlight() {
    var created;
    highlightEl = $(el, '.atropos-highlight');

    if (!highlightEl) {
      highlightEl = document.createElement('span');
      highlightEl.classList.add('atropos-highlight');
      created = true;
    }

    $setTransform(highlightEl, "translate3d(0,0,0)");

    if (created) {
      innerEl.appendChild(highlightEl);
    }
  };

  var setChildrenOffset = function setChildrenOffset(_ref) {
    var _ref$rotateXPercentag = _ref.rotateXPercentage,
        rotateXPercentage = _ref$rotateXPercentag === void 0 ? 0 : _ref$rotateXPercentag,
        _ref$rotateYPercentag = _ref.rotateYPercentage,
        rotateYPercentage = _ref$rotateYPercentag === void 0 ? 0 : _ref$rotateYPercentag,
        duration = _ref.duration,
        opacityOnly = _ref.opacityOnly,
        easeOut = _ref.easeOut;

    var getOpacity = function getOpacity(element) {
      if (element.dataset.atroposOpacity && typeof element.dataset.atroposOpacity === 'string') {
        return element.dataset.atroposOpacity.split(';').map(function (v) {
          return parseFloat(v);
        });
      }

      return undefined;
    };

    $$(el, '[data-atropos-offset], [data-atropos-opacity]').forEach(function (childEl) {
      $setDuration(childEl, duration);
      $setEasing(childEl, easeOut ? 'ease-out' : '');
      var elementOpacity = getOpacity(childEl);

      if (rotateXPercentage === 0 && rotateYPercentage === 0) {
        if (!opacityOnly) $setTransform(childEl, "translate3d(0, 0, 0)");
        if (elementOpacity) $setOpacity(childEl, elementOpacity[0]);
      } else {
        var childElOffset = parseFloat(childEl.dataset.atroposOffset) / 100;

        if (!Number.isNaN(childElOffset) && !opacityOnly) {
          $setTransform(childEl, "translate3d(" + -rotateYPercentage * -childElOffset + "%, " + rotateXPercentage * -childElOffset + "%, 0)");
        }

        if (elementOpacity) {
          var min = elementOpacity[0],
              max = elementOpacity[1];
          var rotatePercentage = Math.max(Math.abs(rotateXPercentage), Math.abs(rotateYPercentage));
          $setOpacity(childEl, min + (max - min) * rotatePercentage / 100);
        }
      }
    });
  };

  var setElements = function setElements(clientX, clientY) {
    var isMultiple = el !== eventsEl;

    if (!elBoundingClientRect) {
      elBoundingClientRect = el.getBoundingClientRect();
    }

    if (isMultiple && !eventsElBoundingClientRect) {
      eventsElBoundingClientRect = eventsEl.getBoundingClientRect();
    }

    if (typeof clientX === 'undefined' && typeof clientY === 'undefined') {
      var rect = isMultiple ? eventsElBoundingClientRect : elBoundingClientRect;
      clientX = rect.left + rect.width / 2;
      clientY = rect.top + rect.height / 2;
    }

    var rotateX = 0;
    var rotateY = 0;
    var _elBoundingClientRect = elBoundingClientRect,
        top = _elBoundingClientRect.top,
        left = _elBoundingClientRect.left,
        width = _elBoundingClientRect.width,
        height = _elBoundingClientRect.height;
    var transformOrigin;

    if (!isMultiple) {
      var centerX = width / 2;
      var centerY = height / 2;
      var coordX = clientX - left;
      var coordY = clientY - top;
      rotateY = params.rotateYMax * (coordX - centerX) / (width / 2) * -1;
      rotateX = params.rotateXMax * (coordY - centerY) / (height / 2);
    } else {
      var _eventsElBoundingClie = eventsElBoundingClientRect,
          parentTop = _eventsElBoundingClie.top,
          parentLeft = _eventsElBoundingClie.left,
          parentWidth = _eventsElBoundingClie.width,
          parentHeight = _eventsElBoundingClie.height;
      var offsetLeft = left - parentLeft;
      var offsetTop = top - parentTop;

      var _centerX = width / 2 + offsetLeft;

      var _centerY = height / 2 + offsetTop;

      var _coordX = clientX - parentLeft;

      var _coordY = clientY - parentTop;

      rotateY = params.rotateYMax * (_coordX - _centerX) / (parentWidth - width / 2) * -1;
      rotateX = params.rotateXMax * (_coordY - _centerY) / (parentHeight - height / 2);
      transformOrigin = clientX - left + "px " + (clientY - top) + "px";
    }

    rotateX = Math.min(Math.max(-rotateX, -params.rotateXMax), params.rotateXMax);
    if (params.rotateXInvert) rotateX = -rotateX;
    rotateY = Math.min(Math.max(-rotateY, -params.rotateYMax), params.rotateYMax);
    if (params.rotateYInvert) rotateY = -rotateY;
    var rotateXPercentage = rotateX / params.rotateXMax * 100;
    var rotateYPercentage = rotateY / params.rotateYMax * 100;
    var stretchX = (isMultiple ? rotateYPercentage / 100 * params.stretchX : 0) * (params.rotateYInvert ? -1 : 1);
    var stretchY = (isMultiple ? rotateXPercentage / 100 * params.stretchY : 0) * (params.rotateXInvert ? -1 : 1);
    var stretchZ = isMultiple ? Math.max(Math.abs(rotateXPercentage), Math.abs(rotateYPercentage)) / 100 * params.stretchZ : 0;
    $setTransform(rotateEl, "translate3d(" + stretchX + "%, " + -stretchY + "%, " + -stretchZ + "px) rotateX(" + rotateX + "deg) rotateY(" + rotateY + "deg)");

    if (transformOrigin && params.commonOrigin) {
      $setOrigin(rotateEl, transformOrigin);
    }

    if (highlightEl) {
      $setDuration(highlightEl, params.duration + "ms");
      $setEasing(highlightEl, 'ease-out');
      $setTransform(highlightEl, "translate3d(" + -rotateYPercentage * 0.25 + "%, " + rotateXPercentage * 0.25 + "%, 0)");
      $setOpacity(highlightEl, Math.max(Math.abs(rotateXPercentage), Math.abs(rotateYPercentage)) / 100);
    }

    setChildrenOffset({
      rotateXPercentage: rotateXPercentage,
      rotateYPercentage: rotateYPercentage,
      duration: params.duration + "ms",
      easeOut: true
    });
    if (typeof params.onRotate === 'function') params.onRotate(rotateX, rotateY);
  };

  var activate = function activate() {
    queue.push(function () {
      return el.classList.add('atropos-active');
    });
    $setDuration(rotateEl, params.duration + "ms");
    $setEasing(rotateEl, 'ease-out');
    $setTransform(scaleEl, "translate3d(0,0, " + params.activeOffset + "px)");
    $setDuration(scaleEl, params.duration + "ms");
    $setEasing(scaleEl, 'ease-out');

    if (shadowEl) {
      $setDuration(shadowEl, params.duration + "ms");
      $setEasing(shadowEl, 'ease-out');
    }

    self.isActive = true;
  };

  var onPointerEnter = function onPointerEnter(e) {
    isScrolling = undefined;
    if (e.type === 'pointerdown' && e.pointerType === 'mouse') return;
    if (e.type === 'pointerenter' && e.pointerType !== 'mouse') return;

    if (e.type === 'pointerdown') {
      e.preventDefault();
    }

    clientXStart = e.clientX;
    clientYStart = e.clientY;

    if (params.alwaysActive) {
      elBoundingClientRect = undefined;
      eventsElBoundingClientRect = undefined;
      return;
    }

    activate();
    if (typeof params.onEnter === 'function') params.onEnter();
  };

  var onTouchMove = function onTouchMove(e) {
    if (isScrolling === false && e.cancelable) {
      e.preventDefault();
    }
  };

  var onPointerMove = function onPointerMove(e) {
    if (!params.rotate || !self.isActive) return;

    if (e.pointerType !== 'mouse') {
      if (!params.rotateTouch) return;
      e.preventDefault();
    }

    var clientX = e.clientX,
        clientY = e.clientY;
    var diffX = clientX - clientXStart;
    var diffY = clientY - clientYStart;

    if (typeof params.rotateTouch === 'string' && (diffX !== 0 || diffY !== 0) && typeof isScrolling === 'undefined') {
      if (diffX * diffX + diffY * diffY >= 25) {
        var touchAngle = Math.atan2(Math.abs(diffY), Math.abs(diffX)) * 180 / Math.PI;
        isScrolling = params.rotateTouch === 'scroll-y' ? touchAngle > 45 : 90 - touchAngle > 45;
      }

      if (isScrolling === false) {
        el.classList.add('atropos-rotate-touch');

        if (e.cancelable) {
          e.preventDefault();
        }
      }
    }

    if (e.pointerType !== 'mouse' && isScrolling) {
      return;
    }

    setElements(clientX, clientY);
  };

  var onPointerLeave = function onPointerLeave(e) {
    elBoundingClientRect = undefined;
    eventsElBoundingClientRect = undefined;
    if (!self.isActive) return;
    if (e && e.type === 'pointerup' && e.pointerType === 'mouse') return;
    if (e && e.type === 'pointerleave' && e.pointerType !== 'mouse') return;

    if (typeof params.rotateTouch === 'string' && isScrolling) {
      el.classList.remove('atropos-rotate-touch');
    }

    if (params.alwaysActive) {
      setElements();
      if (typeof params.onRotate === 'function') params.onRotate(0, 0);
      if (typeof params.onLeave === 'function') params.onLeave();
      return;
    }

    queue.push(function () {
      return el.classList.remove('atropos-active');
    });
    $setDuration(scaleEl, params.duration + "ms");
    $setEasing(scaleEl, '');
    $setTransform(scaleEl, "translate3d(0,0, " + 0 + "px)");

    if (shadowEl) {
      $setDuration(shadowEl, params.duration + "ms");
      $setEasing(shadowEl, '');
    }

    if (highlightEl) {
      $setDuration(highlightEl, params.duration + "ms");
      $setEasing(highlightEl, '');
      $setTransform(highlightEl, "translate3d(0, 0, 0)");
      $setOpacity(highlightEl, 0);
    }

    $setDuration(rotateEl, params.duration + "ms");
    $setEasing(rotateEl, '');
    $setTransform(rotateEl, "translate3d(0,0,0) rotateX(0deg) rotateY(0deg)");
    setChildrenOffset({
      duration: params.duration + "ms"
    });
    self.isActive = false;
    if (typeof params.onRotate === 'function') params.onRotate(0, 0);
    if (typeof params.onLeave === 'function') params.onLeave();
  };

  var onDocumentClick = function onDocumentClick(e) {
    var clickTarget = e.target;

    if (!eventsEl.contains(clickTarget) && clickTarget !== eventsEl && self.isActive) {
      onPointerLeave();
    }
  };

  var initDOM = function initDOM() {
    if (typeof el === 'string') {
      el = $(document, el);
    }

    if (!el) return; // eslint-disable-next-line

    if (el.__atropos__) return;

    if (typeof eventsEl !== 'undefined') {
      if (typeof eventsEl === 'string') {
        eventsEl = $(document, eventsEl);
      }
    } else {
      eventsEl = el;
    }

    Object.assign(self, {
      el: el
    });
    rotateEl = $(el, '.atropos-rotate');
    scaleEl = $(el, '.atropos-scale');
    innerEl = $(el, '.atropos-inner'); // eslint-disable-next-line

    el.__atropos__ = self;
  };

  var init = function init() {
    initDOM();
    if (!el || !eventsEl) return;

    if (params.shadow) {
      createShadow();
    }

    if (params.highlight) {
      createHighlight();
    }

    if (params.rotateTouch) {
      if (typeof params.rotateTouch === 'string') {
        el.classList.add("atropos-rotate-touch-" + params.rotateTouch);
      } else {
        el.classList.add('atropos-rotate-touch');
      }
    }

    if ($(el, '[data-atropos-opacity]')) {
      setChildrenOffset({
        opacityOnly: true
      });
    }

    $on(document, 'click', onDocumentClick);
    $on(eventsEl, 'pointerdown', onPointerEnter);
    $on(eventsEl, 'pointerenter', onPointerEnter);
    $on(eventsEl, 'pointermove', onPointerMove);
    $on(eventsEl, 'touchmove', onTouchMove);
    $on(eventsEl, 'pointerleave', onPointerLeave);
    $on(eventsEl, 'pointerup', onPointerLeave);
    $on(eventsEl, 'lostpointercapture', onPointerLeave);

    if (params.alwaysActive) {
      activate();
      setElements();
    }
  };

  var destroy = function destroy() {
    self.destroyed = true;
    cancelAnimationFrame(queueFrameId);
    $off(document, 'click', onDocumentClick);
    $off(eventsEl, 'pointerdown', onPointerEnter);
    $off(eventsEl, 'pointerenter', onPointerEnter);
    $off(eventsEl, 'pointermove', onPointerMove);
    $off(eventsEl, 'touchmove', onTouchMove);
    $off(eventsEl, 'pointerleave', onPointerLeave);
    $off(eventsEl, 'pointerup', onPointerLeave);
    $off(eventsEl, 'lostpointercapture', onPointerLeave); // eslint-disable-next-line

    delete el.__atropos__;
  };

  self.destroy = destroy;
  init(); // eslint-disable-next-line

  return self;
}

const wrCaseCss = ".atropos{position:relative;display:block;-webkit-perspective:1200px;perspective:1200px;-webkit-transform:translate3d(0, 0, 0);transform:translate3d(0, 0, 0)}.atropos-rotate-touch,.atropos-rotate-scroll-x,.atropos-rotate-scroll-y{-webkit-tap-highlight-color:rgba(0, 0, 0, 0);-webkit-touch-callout:none;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none}.atropos-rotate-touch-scroll-y{-ms-touch-action:pan-y;touch-action:pan-y}.atropos-rotate-touch-scroll-x{-ms-touch-action:pan-x;touch-action:pan-x}.atropos-rotate-touch{-ms-touch-action:none;touch-action:none}.atropos-scale,.atropos-rotate{width:100%;height:100%;-webkit-transform-style:preserve-3d;transform-style:preserve-3d;-webkit-transition-property:-webkit-transform;transition-property:-webkit-transform;transition-property:transform;transition-property:transform, -webkit-transform;display:block}.atropos-shadow,.atropos-highlight{position:absolute;pointer-events:none;-webkit-transition-property:opacity, -webkit-transform;transition-property:opacity, -webkit-transform;transition-property:transform, opacity;transition-property:transform, opacity, -webkit-transform;display:block;opacity:0}.atropos-shadow{z-index:-1;background:#000;left:0;top:0;width:100%;height:100%;-webkit-filter:blur(30px);filter:blur(30px)}.atropos-highlight{left:-50%;top:-50%;width:200%;height:200%;background-image:radial-gradient(circle at 50%, rgba(255, 255, 255, 0.25), transparent 50%);z-index:0}.atropos-rotate{position:relative}.atropos-inner{width:100%;height:100%;position:relative;overflow:hidden;-webkit-transform-style:preserve-3d;transform-style:preserve-3d;-webkit-transform:translate3d(0, 0, 0);transform:translate3d(0, 0, 0);display:block}.atropos-active{z-index:1}.atropos-active .atropos-shadow{opacity:1 !important}[data-atropos-offset]{-webkit-transition-property:-webkit-transform;transition-property:-webkit-transform;transition-property:transform;transition-property:transform, -webkit-transform}[data-atropos-opacity]{-webkit-transition-property:opacity;transition-property:opacity}[data-atropos-offset][data-atropos-opacity]{-webkit-transition-property:opacity, -webkit-transform;transition-property:opacity, -webkit-transform;transition-property:transform, opacity;transition-property:transform, opacity, -webkit-transform}:host{display:block;width:100%}.perspective-wrapper{-webkit-perspective:500px;perspective:500px;-webkit-transform-style:preserve-3d;transform-style:preserve-3d}.case-card{-webkit-transition-property:all;transition-property:all;-webkit-transition-timing-function:cubic-bezier(0.4, 0, 0.2, 1);transition-timing-function:cubic-bezier(0.4, 0, 0.2, 1);-webkit-transition-duration:150ms;transition-duration:150ms;transition-duration:150ms;-webkit-transition-timing-function:cubic-bezier(0.4, 0, 1, 1);transition-timing-function:cubic-bezier(0.4, 0, 1, 1);position:relative;width:100%;overflow:hidden}.case-card.mockup-front .case-card__accessory{z-index:0}.case-card__accessory,.case-card__mockup{position:absolute;top:0px;right:0px;bottom:0px;left:0px;z-index:1;margin:0px}.case-card__accessory img,.case-card__mockup img{height:100%;width:100%;-o-object-fit:cover;object-fit:cover;position:absolute;top:0px;right:0px;bottom:0px;left:0px}.case-card .background-image{position:relative;top:0px;right:0px;bottom:0px;left:0px;margin:0px}.case-card .background-image img{height:100%;width:100%;-o-object-fit:cover;object-fit:cover;border-radius:.25rem;display:block}.case-card .case-card__body{bottom:1rem;padding-top:1.25rem}@media (min-width: 375px){.case-card .case-card__body{bottom:1.75rem}}@media (min-width: 768px){.case-card .case-card__body{bottom:2.5rem}}.case-card .case-card__body{position:absolute;z-index:50;left:2.5rem;right:2.5rem}@media (min-width: 375px){.case-card .case-card__body{left:3.5rem;right:3.5rem}}@media (min-width: 768px){.case-card .case-card__body{left:5.5rem;right:5.5rem}}.case-card h2,.case-card h3{margin:0px;color:var(--text-color)}.case-card h2{font-size:1.25rem;line-height:2rem}@media (min-width: 1024px){.case-card h2{font-size:2.5rem;line-height:3.5rem}}.case-card h3{font-size:0.9375rem;line-height:1.5rem;font-weight:400}@media (min-width: 1024px){.case-card h3{font-size:1.25rem;line-height:2rem}}";

let WrCase = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    /**
     * Used in the conversion to make the color rgba. Is the `a` value
     * @deprecated
     */
    this.backgroundOpacity = .2;
    /**
     * Permalink to the case.
     */
    this.href = '#';
  }
  checkForDeprecations() {
  }
  componentWillLoad() {
    this.checkForDeprecations();
  }
  componentDidLoad() {
    this.bindAtropos();
    this.calculateCardColors();
    this.checkImagesOrRemove();
  }
  bindAtropos() {
    Atropos({
      el: this.atroposElement,
      shadow: false,
      highlight: false,
      rotateTouch: false,
    });
  }
  render() {
    return (index.h("a", { class: 'atropos', href: this.href, ref: el => this.atroposElement = el }, index.h("div", { class: 'atropos-scale' }, index.h("div", { class: 'atropos-rotate' }, index.h("div", { class: 'atropos-inner' }, index.h("article", { class: ['case-card'].join(' '), ref: el => this.card = el }, this.renderBackgroundImage(), this.renderBottomLayer(), this.renderTopLayer(), index.h("div", { class: 'case-card__body' }, index.h("h2", { "data-atropos-offset": 5 }, this.caseTitle), index.h("h3", { "data-atropos-offset": 5 }, this.caseSubtitle))))))));
  }
  renderTopLayer() {
    if (!this.topLayer) {
      return;
    }
    return (index.h("figure", { class: 'case-card__accessory', "data-atropos-offset": 2.5, ref: (el) => this.accessoryImageElement = el }, index.h("img", { src: this.topLayer, alt: '' })));
  }
  renderBottomLayer() {
    if (!this.bottomLayer) {
      return;
    }
    return (index.h("figure", { class: 'case-card__mockup', "data-atropos-offset": 1.5, ref: (el) => this.mockupImageElement = el }, index.h("img", { src: this.bottomLayer, alt: '' })));
  }
  /**
   * Renders the background image if supplied.
   * @protected
   */
  renderBackgroundImage() {
    if (!this.backgroundImage) {
      return;
    }
    return (index.h("figure", { class: 'background-image', "data-atropos-offset": 1, ref: (el) => this.backgroundImageElement = el }, index.h("img", { src: this.backgroundImage, alt: '' })));
  }
  /**
   * Calculates the card colors based on the passed background color.
   *
   * @private
   * @noop
   * @deprecated
   */
  calculateCardColors() { }
  checkImagesOrRemove() {
    [
      this.backgroundImageElement,
      this.mockupImageElement,
      this.accessoryImageElement,
    ].forEach(element => {
      if (!element || !element.querySelector) {
        return;
      }
      element.querySelector('img')
        .addEventListener('error', () => {
        element.parentElement.removeChild(element);
      });
    });
  }
};
WrCase.style = wrCaseCss;

exports.wr_case = WrCase;
