import { Component, h, Prop, State, Watch } from '@stencil/core';
import { format } from 'date-fns';
import nl from 'date-fns/locale/nl';
import { ucFirst } from '../../utils/utils';
export class WrBlockMeta {
  componentWillLoad() {
    this.innerData = JSON.parse(this.items);
  }
  watchDidChangeHandler(newValue) {
    this.innerData = JSON.parse(newValue);
  }
  render() {
    return (h("div", { class: 'meta-data__wrapper' }, this.renderData()));
  }
  renderData() {
    return this.innerData.map(item => (h("div", { class: 'meta-data__item' },
      this.renderItemTitle(item),
      this.renderItemValue(item))));
  }
  renderItemTitle(item) {
    return h("label", { class: 'meta-data__label' }, item.label);
  }
  renderItemValue(item) {
    let url;
    try {
      url = new URL(item.value);
    }
    catch (_a) {
      url = false;
    }
    if (url) {
      return h("a", { href: url.href, class: 'meta-data__item' }, url.host.replace('www.', '').replace('/', ''));
    }
    // Check if value is actually a datetime string;
    if (Date.parse(item.value) && item.value.includes('T00')) {
      return this.renderItemWrappingElement(ucFirst(format(Date.parse(item.value), 'LLLL RRRR', { locale: nl })));
    }
    return this.renderItemWrappingElement(item.value);
  }
  /**
   * Creates the element that will display passed content.
   *
   * @param content
   * @private
   */
  renderItemWrappingElement(content) {
    return h("span", { class: 'meta-data__item' }, content);
  }
  static get is() { return "wr-block-meta"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() { return {
    "$": ["wr-block-meta.css"]
  }; }
  static get styleUrls() { return {
    "$": ["wr-block-meta.css"]
  }; }
  static get properties() { return {
    "items": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "items",
      "reflect": false
    }
  }; }
  static get states() { return {
    "innerData": {}
  }; }
  static get watchers() { return [{
      "propName": "items",
      "methodName": "watchDidChangeHandler"
    }]; }
}
