import { Component, Element, h, Prop } from '@stencil/core';
import { Plane } from '../../geometry/Plane';
import { Point } from '../../geometry/Point';
import { throttle } from '../../utils/utils';
export class WrCaseHighlight {
  constructor() {
    this.backgroundX = '50%';
    this.backgroundY = '50%';
  }
  componentDidLoad() {
    this.card.addEventListener('mousemove', throttle(this.handleMouseOver.bind(this), 16));
    this.card.addEventListener('mouseout', this.handleMouseLeave.bind(this));
  }
  handleMouseLeave() {
    const target = this.card;
    target.style.setProperty('--rotate-x', `0deg`);
    target.style.setProperty('--rotate-y', `0deg`);
  }
  handleMouseOver(event) {
    const target = this.card;
    const plane = new Plane(target.clientWidth, target.clientHeight);
    const point = new Point(event.offsetX, event.offsetY);
    const vector = plane.getPointVectorFromCenter(point);
    target.style.setProperty('--rotate-x', `${vector.interval(plane.outerEdge).x * 12}deg`);
    target.style.setProperty('--translate-x', `${vector.interval(plane.outerEdge).x * 12}%`);
    target.style.setProperty('--rotate-y', `${vector.interval(plane.outerEdge).y * 25}deg`);
    target.style.setProperty('--translate-y', `${vector.interval(plane.outerEdge).y * 25}%`);
  }
  render() {
    return (h("div", { class: 'perspective-wrapper' },
      h("article", { class: 'case-card', ref: (el) => this.card = el },
        this.renderImage(),
        h("a", { class: 'case-card__link', href: this.href, "aria-label": `Bekijk ${this.caseTitle}` }),
        h("footer", { class: 'case-card__footer' },
          h("h3", { class: 'is-h6' }, this.caseTitle),
          h("button", { class: 'case-card__button', "aria-label": `Bekijk ${this.caseTitle}` }, this.renderPlayArrow())))));
  }
  renderImage() {
    return h("img", { class: 'case-card__background', loading: 'lazy', src: this.background, alt: '', srcset: this.backgroundSrcSet });
  }
  renderPlayArrow() {
    return (h("svg", { width: '10', height: '12', viewBox: '0 0 10 12', fill: 'none', xmlns: 'http://www.w3.org/2000/svg', class: 'play-arrow' },
      h("path", { d: 'M0 1.49946C0.00724877 1.22427 0.0894759 0.955945 0.238208 0.722137C0.38694 0.48833 0.596797 0.297496 0.846152 0.169301C1.08606 0.0475163 1.35458 -0.0103541 1.62467 0.00151974C1.89476 0.0133936 2.15687 0.0945922 2.38461 0.236936L9.30768 4.74594C9.52148 4.88349 9.69677 5.07099 9.81766 5.29145C9.93855 5.51191 10.0012 5.75836 9.99998 6.00846C9.99911 6.25338 9.93697 6.49439 9.819 6.7105C9.70102 6.92661 9.53077 7.11128 9.32306 7.24843L2.32307 11.7574C2.0971 11.9047 1.83392 11.9882 1.5625 11.9988C1.29107 12.0095 1.02191 11.9467 0.784614 11.8176C0.548105 11.6877 0.350957 11.499 0.213162 11.2707C0.0753673 11.0424 0.00182731 10.7825 0 10.5175L0 1.49946Z', fill: 'currentColor' })));
  }
  static get is() { return "wr-case-highlight"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() { return {
    "$": ["wr-case-highlight.css"]
  }; }
  static get styleUrls() { return {
    "$": ["wr-case-highlight.css"]
  }; }
  static get properties() { return {
    "background": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": true,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "background",
      "reflect": false
    },
    "backgroundSrcSet": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "background-src-set",
      "reflect": false
    },
    "backgroundX": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "background-x",
      "reflect": false,
      "defaultValue": "'50%'"
    },
    "backgroundY": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "background-y",
      "reflect": false,
      "defaultValue": "'50%'"
    },
    "caseTitle": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": true,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "case-title",
      "reflect": false
    },
    "href": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": true,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "href",
      "reflect": false
    }
  }; }
  static get elementRef() { return "host"; }
}
