import { Component, h, Prop } from '@stencil/core';
import Atropos from 'atropos/esm/atropos.esm';
/*
 * design will deliver full sized images to fit in this element.
 * see: https://drive.google.com/drive/u/0/folders/1UQo-8aAS94dGzyNKKaj8dE2sSzS1V98q
 */
export class WrCase {
  constructor() {
    /**
     * Used in the conversion to make the color rgba. Is the `a` value
     * @deprecated
     */
    this.backgroundOpacity = .2;
    /**
     * Permalink to the case.
     */
    this.href = '#';
  }
  checkForDeprecations() {
  }
  componentWillLoad() {
    this.checkForDeprecations();
  }
  componentDidLoad() {
    this.bindAtropos();
    this.calculateCardColors();
    this.checkImagesOrRemove();
  }
  bindAtropos() {
    Atropos({
      el: this.atroposElement,
      shadow: false,
      highlight: false,
      rotateTouch: false,
    });
  }
  render() {
    return (h("a", { class: 'atropos', href: this.href, ref: el => this.atroposElement = el },
      h("div", { class: 'atropos-scale' },
        h("div", { class: 'atropos-rotate' },
          h("div", { class: 'atropos-inner' },
            h("article", { class: ['case-card'].join(' '), ref: el => this.card = el },
              this.renderBackgroundImage(),
              this.renderBottomLayer(),
              this.renderTopLayer(),
              h("div", { class: 'case-card__body' },
                h("h2", { "data-atropos-offset": 5 }, this.caseTitle),
                h("h3", { "data-atropos-offset": 5 }, this.caseSubtitle))))))));
  }
  renderTopLayer() {
    if (!this.topLayer) {
      return;
    }
    return (h("figure", { class: 'case-card__accessory', "data-atropos-offset": 2.5, ref: (el) => this.accessoryImageElement = el },
      h("img", { src: this.topLayer, alt: '' })));
  }
  renderBottomLayer() {
    if (!this.bottomLayer) {
      return;
    }
    return (h("figure", { class: 'case-card__mockup', "data-atropos-offset": 1.5, ref: (el) => this.mockupImageElement = el },
      h("img", { src: this.bottomLayer, alt: '' })));
  }
  /**
   * Renders the background image if supplied.
   * @protected
   */
  renderBackgroundImage() {
    if (!this.backgroundImage) {
      return;
    }
    return (h("figure", { class: 'background-image', "data-atropos-offset": 1, ref: (el) => this.backgroundImageElement = el },
      h("img", { src: this.backgroundImage, alt: '' })));
  }
  /**
   * Calculates the card colors based on the passed background color.
   *
   * @private
   * @noop
   * @deprecated
   */
  calculateCardColors() { }
  checkImagesOrRemove() {
    [
      this.backgroundImageElement,
      this.mockupImageElement,
      this.accessoryImageElement,
    ].forEach(element => {
      if (!element || !element.querySelector) {
        return;
      }
      element.querySelector('img')
        .addEventListener('error', () => {
        element.parentElement.removeChild(element);
      });
    });
  }
  static get is() { return "wr-case"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() { return {
    "$": ["wr-case.css"]
  }; }
  static get styleUrls() { return {
    "$": ["wr-case.css"]
  }; }
  static get properties() { return {
    "caseTitle": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": true,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "The title for this case."
      },
      "attribute": "case-title",
      "reflect": false
    },
    "caseSubtitle": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": true,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "The subtitle used in this card."
      },
      "attribute": "case-subtitle",
      "reflect": false
    },
    "backgroundColor": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": true,
      "optional": false,
      "docs": {
        "tags": [{
            "text": undefined,
            "name": "deprecated"
          }],
        "text": "A css valid color. Preferably hex, will be\nconverted to rgba."
      },
      "attribute": "background-color",
      "reflect": false
    },
    "backgroundOpacity": {
      "type": "number",
      "mutable": false,
      "complexType": {
        "original": "number",
        "resolved": "number",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [{
            "text": undefined,
            "name": "deprecated"
          }],
        "text": "Used in the conversion to make the color rgba. Is the `a` value"
      },
      "attribute": "background-opacity",
      "reflect": false,
      "defaultValue": ".2"
    },
    "backgroundImage": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": true,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "background image URL."
      },
      "attribute": "background-image",
      "reflect": false
    },
    "topLayer": {
      "type": "string",
      "mutable": true,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": true,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Image url for the top image layer."
      },
      "attribute": "top-layer",
      "reflect": false
    },
    "bottomLayer": {
      "type": "string",
      "mutable": true,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": true,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Image url for the lower layer"
      },
      "attribute": "bottom-layer",
      "reflect": false
    },
    "href": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Permalink to the case."
      },
      "attribute": "href",
      "reflect": false,
      "defaultValue": "'#'"
    }
  }; }
}
