import { Component, h, Method, Prop } from '@stencil/core';
export class WrMenuItem {
  getClass() {
    const classes = [];
    classes.push('wr-menu-item');
    classes.push(`wr-menu-item--${this.size}`);
    return classes.join(' ');
  }
  render() {
    return (h("a", { class: this.getClass(), href: this.href },
      h("slot", null),
      this.renderPlayIcon(),
      this.renderBadge()));
  }
  renderPlayIcon() {
    if (!this._isLarge()) {
      return;
    }
    return (h("svg", { width: '10', height: '12', viewBox: '0 0 10 12', fill: 'none', xmlns: 'http://www.w3.org/2000/svg', class: 'play-arrow' },
      h("path", { d: 'M0 1.49946C0.00724877 1.22427 0.0894759 0.955945 0.238208 0.722137C0.38694 0.48833 0.596797 0.297496 0.846152 0.169301C1.08606 0.0475163 1.35458 -0.0103541 1.62467 0.00151974C1.89476 0.0133936 2.15687 0.0945922 2.38461 0.236936L9.30768 4.74594C9.52148 4.88349 9.69677 5.07099 9.81766 5.29145C9.93855 5.51191 10.0012 5.75836 9.99998 6.00846C9.99911 6.25338 9.93697 6.49439 9.819 6.7105C9.70102 6.92661 9.53077 7.11128 9.32306 7.24843L2.32307 11.7574C2.0971 11.9047 1.83392 11.9882 1.5625 11.9988C1.29107 12.0095 1.02191 11.9467 0.784614 11.8176C0.548105 11.6877 0.350957 11.499 0.213162 11.2707C0.0753673 11.0424 0.00182731 10.7825 0 10.5175L0 1.49946Z' })));
  }
  renderBadge() {
    if (!this.badge) {
      return;
    }
    if (this.badge <= 0) {
      return;
    }
    return (h("span", { class: 'badge' }, this.badge));
  }
  /**
   * Checks if the menu item is large.
   */
  async isLarge() {
    return this._isLarge();
  }
  _isLarge() {
    return this.size === 'large';
  }
  static get is() { return "wr-menu-item"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() { return {
    "$": ["wr-menu-item.css"]
  }; }
  static get styleUrls() { return {
    "$": ["wr-menu-item.css"]
  }; }
  static get properties() { return {
    "size": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "'small' | 'large'",
        "resolved": "\"large\" | \"small\"",
        "references": {}
      },
      "required": true,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Menu item size. Either small or large"
      },
      "attribute": "size",
      "reflect": false
    },
    "badge": {
      "type": "number",
      "mutable": false,
      "complexType": {
        "original": "number",
        "resolved": "number",
        "references": {}
      },
      "required": false,
      "optional": true,
      "docs": {
        "tags": [],
        "text": "The badge number [optional]"
      },
      "attribute": "badge",
      "reflect": false
    },
    "href": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": true,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "The permalink for the navigation item."
      },
      "attribute": "href",
      "reflect": false
    }
  }; }
  static get methods() { return {
    "isLarge": {
      "complexType": {
        "signature": "() => Promise<boolean>",
        "parameters": [],
        "references": {
          "Promise": {
            "location": "global"
          }
        },
        "return": "Promise<boolean>"
      },
      "docs": {
        "text": "Checks if the menu item is large.",
        "tags": []
      }
    }
  }; }
}
