import { Component, Event, h, Host, Listen, State } from '@stencil/core';
import anime from 'animejs';
export class WrNavigation {
  constructor() {
    /**
     * The open state. Managed by event listeners.
     */
    this.isOpen = true;
  }
  componentDidLoad() {
    this.loadAnimation();
    this.menuLoaded.emit();
  }
  /**
   * Setups the animation for the navigation.
   * @protected
   */
  loadAnimation() {
    this.tl = anime.timeline({
      easing: 'easeInCubic',
      duration: 300,
      autoplay: false,
    });
    this.tl.add({
      targets: this.navigationElement,
      opacity: 1,
      duration: 0,
    });
    this.tl.add({
      targets: this.navigationElement,
      width: [0, '100vw'],
    });
    this.tl.add({
      targets: this.menuSlotElement.querySelector('slot').assignedElements(),
      delay: anime.stagger(100),
      translateX: ['-2rem', 0],
      opacity: [0, 1],
    });
    this.tl.add({
      targets: this.footerElement,
      translateY: ['2rem', 0],
      opacity: [0, 1],
    }, '-=300');
    this.tl.add({
      targets: this.sidebarSlotElement.querySelector('slot').assignedElements(),
      delay: anime.stagger(100),
      translateX: ['2rem', 0],
      opacity: [0, 1],
    }, '-=300');
  }
  /**
   * Event listener fired when the 'open' event is fired on this element.
   */
  openNavigationListener() {
    if (!this.isOpen) {
      this.tl.reverse();
    }
    this.tl.restart();
    this.isOpen = true;
    this.navigationToggled.emit('opened');
  }
  /**
   * Event listener fired when the 'close' event is fired on this element.
   */
  closeNavigationListener() {
    if (this.isOpen) {
      this.tl.reverse();
    }
    this.tl.play();
    this.isOpen = false;
    this.navigationToggled.emit('closed');
  }
  render() {
    return (h(Host, null,
      h("section", { class: 'navigation', ref: (el) => this.navigationElement = el },
        h("div", { class: 'navigation-content' },
          h("nav", { class: 'navigation-menu', ref: (el) => this.menuSlotElement = el },
            h("slot", { name: 'navigation' })),
          h("aside", { class: 'navigation-sidebar', ref: (el) => this.sidebarSlotElement = el },
            h("slot", null))),
        h("footer", { class: 'navigation-footer', ref: (el) => this.footerElement = el },
          h("hr", null),
          h("div", { class: 'navigation-footer__container' },
            h("slot", { name: 'footer' }))))));
  }
  static get is() { return "wr-navigation"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() { return {
    "$": ["wr-navigation.css"]
  }; }
  static get styleUrls() { return {
    "$": ["wr-navigation.css"]
  }; }
  static get states() { return {
    "isOpen": {}
  }; }
  static get events() { return [{
      "method": "navigationToggled",
      "name": "navigationToggled",
      "bubbles": true,
      "cancelable": true,
      "composed": true,
      "docs": {
        "tags": [],
        "text": "Event fired when the menu is toggled _and_ animation finished.\n\nFires 'opened' when the navigation is open, and 'closed when the navigation is closed."
      },
      "complexType": {
        "original": "'opened' | 'closed'",
        "resolved": "\"closed\" | \"opened\"",
        "references": {}
      }
    }, {
      "method": "menuLoaded",
      "name": "menuLoaded",
      "bubbles": true,
      "cancelable": true,
      "composed": true,
      "docs": {
        "tags": [],
        "text": "This event fires once on load of the navigation."
      },
      "complexType": {
        "original": "void",
        "resolved": "void",
        "references": {}
      }
    }]; }
  static get listeners() { return [{
      "name": "open",
      "method": "openNavigationListener",
      "target": undefined,
      "capture": false,
      "passive": false
    }, {
      "name": "close",
      "method": "closeNavigationListener",
      "target": undefined,
      "capture": false,
      "passive": false
    }]; }
}
