import { Component, Element, h, Host, Prop } from '@stencil/core';
import anime from 'animejs';
export class WrScrollAnimation {
  constructor() {
    /**
     * Should the animation trigger once.
     */
    this.once = false;
    /**
     * Whether the animation should only fade.
     */
    this.noTranslate = false;
    /**
     * Whether the animation should only translate.
     */
    this.noFade = false;
    /**
     * The animation direction.
     */
    this.direction = 'up';
    /**
     * Animation duration.
     */
    this.duration = 300;
  }
  componentWillLoad() {
    this.tl = anime({
      easing: 'linear',
      targets: this.host,
      duration: this.duration,
      translateY: this.getTranslateYValue(),
      translateX: this.getTranslateXValue(),
      opacity: this.getOpacityChange(),
      autoplay: false,
    });
    const intersectionObserver = new IntersectionObserver(([entry]) => {
      if (!entry.isIntersecting) {
        return;
      }
      this.tl.play();
      if (this.once) {
        intersectionObserver.unobserve(this.host);
      }
    });
    intersectionObserver.observe(this.host);
  }
  render() {
    return (h(Host, null,
      h("slot", null)));
  }
  getTranslateYValue() {
    if (!['up', 'down'].includes(this.direction) || this.noTranslate) {
      return ['0rem', '0rem'];
    }
    if (this.direction === 'up') {
      return ['2rem', '0rem'];
    }
    return ['-2rem', '0rem'];
  }
  getTranslateXValue() {
    if (!['left', 'right'].includes(this.direction) || this.noTranslate) {
      return ['0rem', '0rem'];
    }
    if (this.direction === 'right') {
      return ['2rem', '0rem'];
    }
    return ['-2rem', '0rem'];
  }
  getOpacityChange() {
    if (this.noFade) {
      return [1, 1];
    }
    return [0, 1];
  }
  static get is() { return "wr-scroll-animation"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() { return {
    "$": ["wr-scroll-animation.css"]
  }; }
  static get styleUrls() { return {
    "$": ["wr-scroll-animation.css"]
  }; }
  static get properties() { return {
    "once": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Should the animation trigger once."
      },
      "attribute": "once",
      "reflect": false,
      "defaultValue": "false"
    },
    "noTranslate": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Whether the animation should only fade."
      },
      "attribute": "no-translate",
      "reflect": false,
      "defaultValue": "false"
    },
    "noFade": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Whether the animation should only translate."
      },
      "attribute": "no-fade",
      "reflect": false,
      "defaultValue": "false"
    },
    "direction": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "'up' | 'down' | 'left' | 'right'",
        "resolved": "\"down\" | \"left\" | \"right\" | \"up\"",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "The animation direction."
      },
      "attribute": "direction",
      "reflect": false,
      "defaultValue": "'up'"
    },
    "duration": {
      "type": "number",
      "mutable": false,
      "complexType": {
        "original": "number",
        "resolved": "number",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Animation duration."
      },
      "attribute": "duration",
      "reflect": false,
      "defaultValue": "300"
    }
  }; }
  static get elementRef() { return "host"; }
}
