import { Point } from './Point';
export class Vector {
  /**
   * Gets a vector to determine direction between two points
   * @param {number} x The direction this vector goes on the x-axis
   * @param {number} y The direction this vector goes on the y-axis
   */
  constructor(x, y) {
    this.x = x;
    this.y = y;
  }
  /**
   * Returns a normalized version of this vector (between -1 and 1);
   *
   * @return Point
   */
  get normalized() {
    return new Point(this.x / Math.abs(this.x), this.y / Math.abs(this.y));
  }
  /**
   * Returns an interval [-1, 1] of this vector.
   *
   * @param {Point} max
   *
   * @returns {Point}
   */
  interval(max) {
    return new Point(this.x / max.x, this.y / max.y);
  }
}
