/**
 * Uppercase the first letter of a string.
 * @param {string} str
 *
 * @return {string}
 */
export function ucFirst(str) {
  return str[0].toUpperCase() + str.substring(1);
}
/*
 * Last modified: 17/06/2021, 18:09
 * Copyright (c) 2021 - Webreact
 */
/**
 * Ensures the passed function is only called once per wait.
 *
 * @param fn
 * @param {number} wait
 * @returns {(function(): void)|*}
 */
export const throttle = (fn, wait) => {
  let inThrottle, lastFn, lastTime;
  return function () {
    const context = this, args = arguments;
    if (!inThrottle) {
      fn.apply(context, args);
      lastTime = Date.now();
      inThrottle = true;
    }
    else {
      clearTimeout(lastFn);
      lastFn = setTimeout(function () {
        if (Date.now() - lastTime >= wait) {
          fn.apply(context, args);
          lastTime = Date.now();
        }
      }, Math.max(wait - (Date.now() - lastTime), 0));
    }
  };
};
/**
 * Enter a number, round it to the nearest 10 [1 -> 0, 5 -> 10]
 *
 * @param {number} n
 */
export const round10 = (n) => {
  return roundToBase(n, 10);
};
/**
 * Round a number to the nearest base
 * @param {number} n
 * @param {number} base
 */
export const roundToBase = (n, base) => {
  return Math.round(n / base) * base;
};
