import { r as registerInstance, c as createEvent, h } from './index-e41e20bc.js';
import { a as anime } from './anime.es-d8ec8d88.js';

const wrAccordionCss = ":host{display:block}*{-webkit-box-sizing:border-box;box-sizing:border-box}.accordion{position:relative;overflow:hidden}.accordion__background{position:absolute;top:0px;right:0px;bottom:0px;left:0px;-webkit-transition-property:opacity;transition-property:opacity;-webkit-transition-timing-function:cubic-bezier(0.4, 0, 0.2, 1);transition-timing-function:cubic-bezier(0.4, 0, 0.2, 1);-webkit-transition-duration:150ms;transition-duration:150ms;-webkit-transition-duration:200ms;transition-duration:200ms;-webkit-transition-timing-function:cubic-bezier(0.4, 0, 1, 1);transition-timing-function:cubic-bezier(0.4, 0, 1, 1);margin:0px;opacity:0;display:none}@media (min-width: 1024px){.accordion__background{display:block}}.accordion__background img{position:absolute;top:0px;right:0px;bottom:0px;left:0px;height:100%;width:100%;-o-object-fit:cover;object-fit:cover}.accordion__background.active{opacity:0.6 !important}.accordion__content{-webkit-transition-property:all;transition-property:all;-webkit-transition-timing-function:cubic-bezier(0.4, 0, 0.2, 1);transition-timing-function:cubic-bezier(0.4, 0, 0.2, 1);-webkit-transition-duration:150ms;transition-duration:150ms;-webkit-transition-delay:75ms;transition-delay:75ms;-webkit-transition-duration:300ms;transition-duration:300ms;transition-timing-function:cubic-bezier(0.4, 0, 0.2, 1)}@media (min-width: 1024px){.accordion__content{margin-left:auto;margin-right:auto}.accordion__content{width:83.333333%}}.accordion__content{--tw-text-opacity:1;color:rgba(255, 255, 255, var(--tw-text-opacity));padding-top:1rem;padding-bottom:1rem;padding-left:0px;padding-right:0px;font-size:1.0625rem;line-height:1.75rem;position:relative;opacity:0}.accordion__header{display:-ms-flexbox;display:flex;padding-top:1.25rem;padding-bottom:1.25rem;padding-left:0px;padding-right:0px}@media (min-width: 768px){.accordion__header{padding-top:1.5rem;padding-bottom:1.5rem}}.accordion__header{border-bottom-width:1px;cursor:pointer;position:relative;z-index:10;border-width:0px;border-bottom-width:1px;border-style:solid;border-color:rgba(255, 255, 255, 0.25)}@media (min-width: 1024px){.accordion__header{margin-left:auto;margin-right:auto}.accordion__header{width:83.333333%}}.accordion__title{font-size:2rem;line-height:2.75rem;--tw-text-opacity:1;color:rgba(255, 255, 255, var(--tw-text-opacity));margin-top:0px;margin-bottom:0px}.accordion__button{border-width:0px;background-color:transparent;height:1.25rem;width:1.25rem}@media (min-width: 768px){.accordion__button{height:1.5rem}.accordion__button{width:1.5rem}}.accordion__button{margin:auto;margin-right:0px;cursor:pointer;overflow:hidden;position:relative;z-index:1}.accordion__button span{-webkit-transition-property:all;transition-property:all;-webkit-transition-timing-function:cubic-bezier(0.4, 0, 0.2, 1);transition-timing-function:cubic-bezier(0.4, 0, 0.2, 1);-webkit-transition-duration:150ms;transition-duration:150ms;-webkit-transition-duration:225ms;transition-duration:225ms;transition-timing-function:cubic-bezier(0.4, 0, 0.2, 1);position:absolute;left:0px;right:0px;--tw-bg-opacity:1;background-color:rgba(255, 255, 255, var(--tw-bg-opacity));display:block;height:2px}.accordion__button span:nth-of-type(2){-webkit-transform:rotate(90deg);transform:rotate(90deg)}.accordion__button.active span:nth-of-type(2){-webkit-transform:rotate(0);transform:rotate(0)}.accordion:hover .accordion__background{opacity:0.3}.accordion:hover .accordion__button:not(.active) span:nth-of-type(2){-webkit-animation:225ms button-nudge;animation:225ms button-nudge}@-webkit-keyframes button-nudge{0%,50%,100%{-webkit-transform:rotate(90deg);transform:rotate(90deg)}25%{-webkit-transform:rotate(85deg);transform:rotate(85deg)}75%{-webkit-transform:rotate(95deg);transform:rotate(95deg)}}@keyframes button-nudge{0%,50%,100%{-webkit-transform:rotate(90deg);transform:rotate(90deg)}25%{-webkit-transform:rotate(85deg);transform:rotate(85deg)}75%{-webkit-transform:rotate(95deg);transform:rotate(95deg)}}";

let WrAccordion = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.accordionOpened = createEvent(this, "accordionOpened", 7);
    /**
     * The initial state. This is set to open in case the JS errors and to fire the correct closing event
     * on initial render.
     */
    this.open = true;
    this.sizes = {};
  }
  /**
   * Lifecycle hook to close the component after render. Should the script error before loading the content is still
   * readable.
   */
  async componentDidLoad() {
    const resizeObserver = new ResizeObserver(() => this.calculateSizes());
    await this.calculateSizes();
    this.open = false;
    this.checkBackgroundImage();
    resizeObserver.observe(this.accordion);
  }
  async watchOpen(newValue) {
    if (newValue)
      this.accordionOpened.emit('starting');
    let elementHeight;
    const tl = anime.timeline({
      easing: newValue ? 'easeInCubic' : 'easeOutCubic',
      duration: 300,
    });
    if (newValue) {
      elementHeight = this.sizes.openedSize;
    }
    else {
      elementHeight = this.sizes.closedSize;
    }
    if (newValue)
      this.accordionOpened.emit('animating');
    // Set the accordion to either full height or the header height.
    tl.add({
      targets: this.accordion,
      height: elementHeight,
    });
    if (this.background) {
      // Set the background to either full height or the header height.
      tl.add({
        targets: this.backgroundElement,
        height: elementHeight,
      }, 0);
      // Scale the background to fit.
      tl.add({
        targets: this.backgroundElement,
        scale: newValue ? [1, 1.25] : [1.25, 1],
      }, '+=150');
    }
    // Flow in the content.
    tl.add({
      targets: this.contentElement,
      translateY: newValue ? ['-2rem', 0] : [0, '-2rem'],
      opacity: newValue ? [0, 0, 100] : [100, 0],
    }, this.background ? '-=300' : 0);
    if (newValue)
      this.accordionOpened.emit('processed');
  }
  async closeMe() {
    this.open = false;
  }
  async openMe() {
    this.open = true;
  }
  render() {
    return (h("article", { ref: (el) => this.accordion = el, class: ['accordion', this.open ? 'active' : ''].join(' ') }, this.renderImage(), h("header", { class: 'accordion__header', onClick: () => this.open = !this.open }, h("h3", { class: 'accordion__title' }, this.accordionTitle), this.renderStateButton()), h("section", { class: 'accordion__content', ref: (el) => this.contentElement = el, "aria-hidden": this.open ? 'true' : 'false' }, h("slot", null))));
  }
  renderStateButton() {
    return (h("button", { class: ['accordion__button', this.open ? 'active' : ''].join(' '), name: `${this.open ? 'Verberg' : 'Toon'} de inhoud van ${this.accordionTitle}` }, h("span", null), h("span", null)));
  }
  /**
   * Renders the background image for the accordion if supplied.
   *
   * Has a built-in check for errors to remove itself in prevention of default image error.
   */
  renderImage() {
    if (!this.background) {
      return;
    }
    return (h("figure", { class: ['accordion__background', this.open ? 'active' : ''].join(' '), ref: (el) => this.backgroundElement = el }, h("img", { src: this.background, alt: '' })));
  }
  /**
   * Recalculate te sizes of the accordion.
   */
  async calculateSizes() {
    const headerHeight = this.accordion.querySelector('.accordion__header').clientHeight + 1; // Add 1 px for the bottom border.
    this.sizes.openedSize = headerHeight + this.contentElement.clientHeight;
    this.sizes.closedSize = headerHeight;
  }
  /**
   * Checks if the accordion background image should exist.
   * @protected
   */
  checkBackgroundImage() {
    if (this.backgroundElement) {
      this.backgroundElement.querySelector('img')
        .addEventListener('error', () => {
        this.backgroundElement.parentElement.removeChild(this.backgroundElement);
        this.background = null;
      });
    }
  }
  static get watchers() { return {
    "open": ["watchOpen"]
  }; }
};
WrAccordion.style = wrAccordionCss;

export { WrAccordion as wr_accordion };
