import { EventEmitter } from '../../stencil-public-runtime';
export declare class WrAccordion {
  /**
   * The title for the accordion. This is always shown.
   */
  accordionTitle: string;
  /**
   * The background image which scales when opening.
   */
  background: string;
  /**
   * The initial state. This is set to open in case the JS errors and to fire the correct closing event
   * on initial render.
   */
  open: boolean;
  sizes: {
    closedSize?: number;
    openedSize?: number;
  };
  /**
   * Fires when the element is opened. The Event.detail property is a string
   * set to the current opening state.
   *
   * Event fires the following 3 times:
   *   - `starting`
   *   - `animating`
   *   - `processed`
   */
  accordionOpened: EventEmitter<string>;
  /**
   * The accordion self
   */
  accordion: HTMLElement;
  /**
   * The content element. Used to calculate the height
   */
  contentElement: HTMLElement;
  /**
   * The background image.
   */
  backgroundElement: HTMLElement;
  /**
   * Lifecycle hook to close the component after render. Should the script error before loading the content is still
   * readable.
   */
  componentDidLoad(): Promise<void>;
  watchOpen(newValue: boolean): Promise<void>;
  closeMe(): Promise<void>;
  openMe(): Promise<void>;
  render(): any;
  protected renderStateButton(): any;
  /**
   * Renders the background image for the accordion if supplied.
   *
   * Has a built-in check for errors to remove itself in prevention of default image error.
   */
  protected renderImage(): any;
  /**
   * Recalculate te sizes of the accordion.
   */
  calculateSizes(): Promise<void>;
  /**
   * Checks if the accordion background image should exist.
   * @protected
   */
  protected checkBackgroundImage(): void;
}
